# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'led_control_widget.ui',
# licensing of 'led_control_widget.ui' applies.
#
# Created: Sun Mar 31 19:42:17 2019
#      by: pyside2-uic  running on PySide2 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_LEDControlWidget(object):
    def setupUi(self, LEDControlWidget):
        LEDControlWidget.setObjectName("LEDControlWidget")
        LEDControlWidget.resize(176, 20)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(LEDControlWidget)
        self.horizontalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.slider = QtWidgets.QSlider(LEDControlWidget)
        self.slider.setMinimumSize(QtCore.QSize(128, 0))
        self.slider.setMaximum(255)
        self.slider.setOrientation(QtCore.Qt.Horizontal)
        self.slider.setObjectName("slider")
        self.horizontalLayout_3.addWidget(self.slider)
        self.spinBox = QtWidgets.QSpinBox(LEDControlWidget)
        self.spinBox.setMaximum(255)
        self.spinBox.setObjectName("spinBox")
        self.horizontalLayout_3.addWidget(self.spinBox)

        self.retranslateUi(LEDControlWidget)
        QtCore.QObject.connect(self.slider, QtCore.SIGNAL("valueChanged(int)"), self.spinBox.setValue)
        QtCore.QObject.connect(self.spinBox, QtCore.SIGNAL("valueChanged(int)"), self.slider.setValue)
        QtCore.QMetaObject.connectSlotsByName(LEDControlWidget)
        LEDControlWidget.setTabOrder(self.slider, self.spinBox)

    def retranslateUi(self, LEDControlWidget):
        LEDControlWidget.setWindowTitle(QtWidgets.QApplication.translate("LEDControlWidget", "LED Control Widget", None, -1))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'connect_tcp_dialog.ui',
# licensing of 'connect_tcp_dialog.ui' applies.
#
# Created: Mon Apr 20 10:50:17 2020
#      by: pyside2-uic  running on PySide2 5.13.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_ConnectTCPDialog(object):
    def setupUi(self, ConnectTCPDialog):
        ConnectTCPDialog.setObjectName("ConnectTCPDialog")
        ConnectTCPDialog.resize(341, 119)
        self.formLayout = QtWidgets.QFormLayout(ConnectTCPDialog)
        self.formLayout.setObjectName("formLayout")
        self.hostnameLabel = QtWidgets.QLabel(ConnectTCPDialog)
        self.hostnameLabel.setObjectName("hostnameLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.hostnameLabel)
        self.hostname = QtWidgets.QLineEdit(ConnectTCPDialog)
        self.hostname.setMinimumSize(QtCore.QSize(200, 0))
        self.hostname.setObjectName("hostname")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.hostname)
        self.portLabel = QtWidgets.QLabel(ConnectTCPDialog)
        self.portLabel.setObjectName("portLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.portLabel)
        self.port = QtWidgets.QSpinBox(ConnectTCPDialog)
        self.port.setMinimum(1)
        self.port.setMaximum(65535)
        self.port.setProperty("value", 5760)
        self.port.setObjectName("port")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.port)
        self.serialLabel = QtWidgets.QLabel(ConnectTCPDialog)
        self.serialLabel.setObjectName("serialLabel")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.serialLabel)
        self.serial = QtWidgets.QLineEdit(ConnectTCPDialog)
        self.serial.setObjectName("serial")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.serial)
        self.buttonBox = QtWidgets.QDialogButtonBox(ConnectTCPDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.SpanningRole, self.buttonBox)

        self.retranslateUi(ConnectTCPDialog)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("accepted()"), ConnectTCPDialog.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("rejected()"), ConnectTCPDialog.reject)
        QtCore.QMetaObject.connectSlotsByName(ConnectTCPDialog)

    def retranslateUi(self, ConnectTCPDialog):
        ConnectTCPDialog.setWindowTitle(QtWidgets.QApplication.translate("ConnectTCPDialog", "Connect TCP Device", None, -1))
        self.hostnameLabel.setText(QtWidgets.QApplication.translate("ConnectTCPDialog", "Hostname", None, -1))
        self.portLabel.setToolTip(QtWidgets.QApplication.translate("ConnectTCPDialog", "Default: 5760", None, -1))
        self.portLabel.setText(QtWidgets.QApplication.translate("ConnectTCPDialog", "Port", None, -1))
        self.port.setToolTip(QtWidgets.QApplication.translate("ConnectTCPDialog", "Default: 5760", None, -1))
        self.serialLabel.setText(QtWidgets.QApplication.translate("ConnectTCPDialog", "Serial Number (Optional)", None, -1))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'remote_panel.ui',
# licensing of 'remote_panel.ui' applies.
#
# Created: Sun Mar 31 19:42:17 2019
#      by: pyside2-uic  running on PySide2 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_RemotePanel(object):
    def setupUi(self, RemotePanel):
        RemotePanel.setObjectName("RemotePanel")
        RemotePanel.resize(112, 182)
        self.verticalLayout = QtWidgets.QVBoxLayout(RemotePanel)
        self.verticalLayout.setObjectName("verticalLayout")
        spacerItem = QtWidgets.QSpacerItem(10, 10, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem)
        self.goToParentButton = QtWidgets.QPushButton(RemotePanel)
        self.goToParentButton.setObjectName("goToParentButton")
        self.verticalLayout.addWidget(self.goToParentButton)

        self.retranslateUi(RemotePanel)
        QtCore.QMetaObject.connectSlotsByName(RemotePanel)

    def retranslateUi(self, RemotePanel):
        RemotePanel.setWindowTitle(QtWidgets.QApplication.translate("RemotePanel", "Remote Device Panel", None, -1))
        RemotePanel.setTitle(QtWidgets.QApplication.translate("RemotePanel", "Remote Device", None, -1))
        self.goToParentButton.setText(QtWidgets.QApplication.translate("RemotePanel", "Go To Radio Tab", None, -1))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'device_tab.ui',
# licensing of 'device_tab.ui' applies.
#
# Created: Thu May 14 10:32:19 2020
#      by: pyside2-uic  running on PySide2 5.13.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_DeviceTab(object):
    def setupUi(self, DeviceTab):
        DeviceTab.setObjectName("DeviceTab")
        DeviceTab.resize(1004, 600)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(DeviceTab)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.formLayout_2 = QtWidgets.QFormLayout()
        self.formLayout_2.setObjectName("formLayout_2")
        self.graphChannelComboBox = QtWidgets.QComboBox(DeviceTab)
        self.graphChannelComboBox.setMinimumSize(QtCore.QSize(200, 0))
        self.graphChannelComboBox.setMaxVisibleItems(20)
        self.graphChannelComboBox.setObjectName("graphChannelComboBox")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.graphChannelComboBox)
        self.graphChannelLabel = QtWidgets.QLabel(DeviceTab)
        self.graphChannelLabel.setObjectName("graphChannelLabel")
        self.formLayout_2.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.graphChannelLabel)
        self.fftSubchannelComboBox = QtWidgets.QComboBox(DeviceTab)
        self.fftSubchannelComboBox.setMinimumSize(QtCore.QSize(200, 0))
        self.fftSubchannelComboBox.setMaxVisibleItems(20)
        self.fftSubchannelComboBox.setObjectName("fftSubchannelComboBox")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.fftSubchannelComboBox)
        self.fftSubchannelLabel = QtWidgets.QLabel(DeviceTab)
        self.fftSubchannelLabel.setObjectName("fftSubchannelLabel")
        self.formLayout_2.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.fftSubchannelLabel)
        self.horizontalLayout.addLayout(self.formLayout_2)
        spacerItem = QtWidgets.QSpacerItem(40, 0, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem)
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        spacerItem1 = QtWidgets.QSpacerItem(40, 10, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem1, 0, 2, 1, 1)
        self.serialNumberLabel = QtWidgets.QLabel(DeviceTab)
        self.serialNumberLabel.setObjectName("serialNumberLabel")
        self.gridLayout.addWidget(self.serialNumberLabel, 0, 0, 1, 1)
        self.userTag2 = QtWidgets.QLabel(DeviceTab)
        self.userTag2.setObjectName("userTag2")
        self.gridLayout.addWidget(self.userTag2, 2, 1, 1, 1)
        self.userTag1 = QtWidgets.QLabel(DeviceTab)
        self.userTag1.setObjectName("userTag1")
        self.gridLayout.addWidget(self.userTag1, 1, 1, 1, 1)
        self.userTag2Label = QtWidgets.QLabel(DeviceTab)
        self.userTag2Label.setObjectName("userTag2Label")
        self.gridLayout.addWidget(self.userTag2Label, 2, 0, 1, 1)
        self.serialNumber = QtWidgets.QLabel(DeviceTab)
        self.serialNumber.setObjectName("serialNumber")
        self.gridLayout.addWidget(self.serialNumber, 0, 1, 1, 1)
        self.userTag1Label = QtWidgets.QLabel(DeviceTab)
        self.userTag1Label.setObjectName("userTag1Label")
        self.gridLayout.addWidget(self.userTag1Label, 1, 0, 1, 1)
        self.boardInfoLabel = QtWidgets.QLabel(DeviceTab)
        self.boardInfoLabel.setObjectName("boardInfoLabel")
        self.gridLayout.addWidget(self.boardInfoLabel, 0, 3, 1, 1)
        self.boardInfo = QtWidgets.QLabel(DeviceTab)
        self.boardInfo.setObjectName("boardInfo")
        self.gridLayout.addWidget(self.boardInfo, 0, 4, 1, 1)
        self.buildInfoLabel = QtWidgets.QLabel(DeviceTab)
        self.buildInfoLabel.setObjectName("buildInfoLabel")
        self.gridLayout.addWidget(self.buildInfoLabel, 1, 3, 1, 1)
        self.buildInfo = QtWidgets.QLabel(DeviceTab)
        self.buildInfo.setObjectName("buildInfo")
        self.gridLayout.addWidget(self.buildInfo, 1, 4, 1, 1)
        self.buildDateLabel = QtWidgets.QLabel(DeviceTab)
        self.buildDateLabel.setObjectName("buildDateLabel")
        self.gridLayout.addWidget(self.buildDateLabel, 2, 3, 1, 1)
        self.buildDate = QtWidgets.QLabel(DeviceTab)
        self.buildDate.setObjectName("buildDate")
        self.gridLayout.addWidget(self.buildDate, 2, 4, 1, 1)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.gridLayout.addItem(spacerItem2, 0, 5, 1, 1)
        self.bootloaderIndicator = QtWidgets.QLabel(DeviceTab)
        self.bootloaderIndicator.setStyleSheet("QLabel { background-color : yellow ; font-weight : bold ; font-size : 12px ; }")
        self.bootloaderIndicator.setMargin(10)
        self.bootloaderIndicator.setObjectName("bootloaderIndicator")
        self.gridLayout.addWidget(self.bootloaderIndicator, 0, 6, 3, 1)
        self.horizontalLayout.addLayout(self.gridLayout)
        spacerItem3 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem3)
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.closeButton = QtWidgets.QPushButton(DeviceTab)
        self.closeButton.setObjectName("closeButton")
        self.verticalLayout.addWidget(self.closeButton)
        self.menuButton = QtWidgets.QPushButton(DeviceTab)
        self.menuButton.setEnabled(False)
        self.menuButton.setObjectName("menuButton")
        self.verticalLayout.addWidget(self.menuButton)
        self.horizontalLayout.addLayout(self.verticalLayout)
        self.verticalLayout_2.addLayout(self.horizontalLayout)
        self.stackedWidget = QtWidgets.QStackedWidget(DeviceTab)
        self.stackedWidget.setObjectName("stackedWidget")
        self.disconnectPage = QtWidgets.QWidget()
        self.disconnectPage.setObjectName("disconnectPage")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.disconnectPage)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        spacerItem4 = QtWidgets.QSpacerItem(0, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem4)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        spacerItem5 = QtWidgets.QSpacerItem(20, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem5)
        self.statusLabel = QtWidgets.QLabel(self.disconnectPage)
        font = QtGui.QFont()
        font.setWeight(75)
        font.setBold(True)
        self.statusLabel.setFont(font)
        self.statusLabel.setAlignment(QtCore.Qt.AlignCenter)
        self.statusLabel.setObjectName("statusLabel")
        self.verticalLayout_3.addWidget(self.statusLabel)
        self.statusProgressBar = QtWidgets.QProgressBar(self.disconnectPage)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.statusProgressBar.sizePolicy().hasHeightForWidth())
        self.statusProgressBar.setSizePolicy(sizePolicy)
        self.statusProgressBar.setMinimumSize(QtCore.QSize(175, 0))
        self.statusProgressBar.setProperty("value", 24)
        self.statusProgressBar.setAlignment(QtCore.Qt.AlignCenter)
        self.statusProgressBar.setObjectName("statusProgressBar")
        self.verticalLayout_3.addWidget(self.statusProgressBar)
        spacerItem6 = QtWidgets.QSpacerItem(20, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem6)
        self.horizontalLayout_4.addLayout(self.verticalLayout_3)
        spacerItem7 = QtWidgets.QSpacerItem(0, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem7)
        self.stackedWidget.addWidget(self.disconnectPage)
        self.displayPage = QtWidgets.QWidget()
        self.displayPage.setObjectName("displayPage")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.displayPage)
        self.verticalLayout_5.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.panelLayout = QtWidgets.QHBoxLayout()
        self.panelLayout.setObjectName("panelLayout")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.graphicsLayout = GraphicsLayoutWidget(self.displayPage)
        self.graphicsLayout.setObjectName("graphicsLayout")
        self.verticalLayout_4.addWidget(self.graphicsLayout)
        self.panelLayout.addLayout(self.verticalLayout_4)
        self.panelLayout.setStretch(0, 1)
        self.verticalLayout_5.addLayout(self.panelLayout)
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.channelGroupBox = QtWidgets.QGroupBox(self.displayPage)
        self.channelGroupBox.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.channelGroupBox.setObjectName("channelGroupBox")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.channelGroupBox)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.channelLayout = QtWidgets.QGridLayout()
        self.channelLayout.setObjectName("channelLayout")
        self.meanLabel = QtWidgets.QLabel(self.channelGroupBox)
        self.meanLabel.setMinimumSize(QtCore.QSize(100, 0))
        self.meanLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.meanLabel.setObjectName("meanLabel")
        self.channelLayout.addWidget(self.meanLabel, 0, 1, 1, 1)
        self.samplingRateLabel = QtWidgets.QLabel(self.channelGroupBox)
        self.samplingRateLabel.setMinimumSize(QtCore.QSize(100, 0))
        self.samplingRateLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.samplingRateLabel.setObjectName("samplingRateLabel")
        self.channelLayout.addWidget(self.samplingRateLabel, 0, 3, 1, 1)
        self.stdDevLabel = QtWidgets.QLabel(self.channelGroupBox)
        self.stdDevLabel.setMinimumSize(QtCore.QSize(100, 0))
        self.stdDevLabel.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.stdDevLabel.setObjectName("stdDevLabel")
        self.channelLayout.addWidget(self.stdDevLabel, 0, 2, 1, 1)
        self.channelLabel = QtWidgets.QLabel(self.channelGroupBox)
        self.channelLabel.setMinimumSize(QtCore.QSize(0, 0))
        self.channelLabel.setText("")
        self.channelLabel.setObjectName("channelLabel")
        self.channelLayout.addWidget(self.channelLabel, 0, 0, 1, 1)
        self.verticalLayout_8.addLayout(self.channelLayout)
        spacerItem8 = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_8.addItem(spacerItem8)
        self.horizontalLayout_3.addWidget(self.channelGroupBox)
        self.LEDGroupBox = QtWidgets.QGroupBox(self.displayPage)
        self.LEDGroupBox.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignTop)
        self.LEDGroupBox.setObjectName("LEDGroupBox")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.LEDGroupBox)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.LEDLayout = QtWidgets.QVBoxLayout()
        self.LEDLayout.setObjectName("LEDLayout")
        self.verticalLayout_7.addLayout(self.LEDLayout)
        spacerItem9 = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_7.addItem(spacerItem9)
        self.horizontalLayout_3.addWidget(self.LEDGroupBox)
        self.logGroupBox = QtWidgets.QGroupBox(self.displayPage)
        self.logGroupBox.setObjectName("logGroupBox")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.logGroupBox)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.logList = QtWidgets.QListWidget(self.logGroupBox)
        self.logList.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOn)
        self.logList.setObjectName("logList")
        self.verticalLayout_9.addWidget(self.logList)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setContentsMargins(-1, 0, -1, -1)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        spacerItem10 = QtWidgets.QSpacerItem(0, 0, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem10)
        self.recentLostPacketsLabel = QtWidgets.QLabel(self.logGroupBox)
        self.recentLostPacketsLabel.setObjectName("recentLostPacketsLabel")
        self.horizontalLayout_2.addWidget(self.recentLostPacketsLabel)
        self.recentLostPackets = QtWidgets.QLineEdit(self.logGroupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.recentLostPackets.sizePolicy().hasHeightForWidth())
        self.recentLostPackets.setSizePolicy(sizePolicy)
        self.recentLostPackets.setMaximumSize(QtCore.QSize(60, 16777215))
        self.recentLostPackets.setMaxLength(10)
        self.recentLostPackets.setAlignment(QtCore.Qt.AlignRight|QtCore.Qt.AlignTrailing|QtCore.Qt.AlignVCenter)
        self.recentLostPackets.setReadOnly(True)
        self.recentLostPackets.setObjectName("recentLostPackets")
        self.horizontalLayout_2.addWidget(self.recentLostPackets)
        self.verticalLayout_9.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_3.addWidget(self.logGroupBox)
        self.horizontalLayout_3.setStretch(2, 1)
        self.verticalLayout_5.addLayout(self.horizontalLayout_3)
        self.verticalLayout_5.setStretch(0, 1)
        self.stackedWidget.addWidget(self.displayPage)
        self.verticalLayout_2.addWidget(self.stackedWidget)
        self.actionSetUserTag1 = QtWidgets.QAction(DeviceTab)
        self.actionSetUserTag1.setObjectName("actionSetUserTag1")
        self.actionSetUserTag2 = QtWidgets.QAction(DeviceTab)
        self.actionSetUserTag2.setObjectName("actionSetUserTag2")
        self.actionEditDeviceSettings = QtWidgets.QAction(DeviceTab)
        self.actionEditDeviceSettings.setObjectName("actionEditDeviceSettings")
        self.actionShowDeviceInfo = QtWidgets.QAction(DeviceTab)
        self.actionShowDeviceInfo.setObjectName("actionShowDeviceInfo")
        self.actionFirmwareLatestStable = QtWidgets.QAction(DeviceTab)
        self.actionFirmwareLatestStable.setEnabled(False)
        self.actionFirmwareLatestStable.setObjectName("actionFirmwareLatestStable")
        self.actionShowPacketStats = QtWidgets.QAction(DeviceTab)
        self.actionShowPacketStats.setObjectName("actionShowPacketStats")
        self.actionChangeActiveStreams = QtWidgets.QAction(DeviceTab)
        self.actionChangeActiveStreams.setObjectName("actionChangeActiveStreams")
        self.actionRunTests = QtWidgets.QAction(DeviceTab)
        self.actionRunTests.setObjectName("actionRunTests")
        self.actionSetDeviceMode = QtWidgets.QAction(DeviceTab)
        self.actionSetDeviceMode.setEnabled(False)
        self.actionSetDeviceMode.setObjectName("actionSetDeviceMode")
        self.actionFirmwareFromBranch = QtWidgets.QAction(DeviceTab)
        self.actionFirmwareFromBranch.setEnabled(False)
        self.actionFirmwareFromBranch.setObjectName("actionFirmwareFromBranch")
        self.actionFirmwareFromCommit = QtWidgets.QAction(DeviceTab)
        self.actionFirmwareFromCommit.setEnabled(False)
        self.actionFirmwareFromCommit.setObjectName("actionFirmwareFromCommit")
        self.actionFirmwareFromFile = QtWidgets.QAction(DeviceTab)
        self.actionFirmwareFromFile.setEnabled(False)
        self.actionFirmwareFromFile.setObjectName("actionFirmwareFromFile")
        self.actionForceRunBootloader = QtWidgets.QAction(DeviceTab)
        self.actionForceRunBootloader.setEnabled(False)
        self.actionForceRunBootloader.setObjectName("actionForceRunBootloader")
        self.actionForceRunApplication = QtWidgets.QAction(DeviceTab)
        self.actionForceRunApplication.setEnabled(False)
        self.actionForceRunApplication.setObjectName("actionForceRunApplication")
        self.actionForceReset = QtWidgets.QAction(DeviceTab)
        self.actionForceReset.setObjectName("actionForceReset")
        self.actionRaiseException = QtWidgets.QAction(DeviceTab)
        self.actionRaiseException.setObjectName("actionRaiseException")
        self.actionRecoverNVM = QtWidgets.QAction(DeviceTab)
        self.actionRecoverNVM.setObjectName("actionRecoverNVM")
        self.actionCalibrate = QtWidgets.QAction(DeviceTab)
        self.actionCalibrate.setCheckable(True)
        self.actionCalibrate.setEnabled(False)
        self.actionCalibrate.setObjectName("actionCalibrate")
        self.actionShakerCalibrate = QtWidgets.QAction(DeviceTab)
        self.actionShakerCalibrate.setEnabled(False)
        self.actionShakerCalibrate.setObjectName("actionShakerCalibrate")

        self.retranslateUi(DeviceTab)
        self.stackedWidget.setCurrentIndex(1)
        QtCore.QMetaObject.connectSlotsByName(DeviceTab)

    def retranslateUi(self, DeviceTab):
        DeviceTab.setWindowTitle(QtWidgets.QApplication.translate("DeviceTab", "Device Tab", None, -1))
        self.graphChannelLabel.setText(QtWidgets.QApplication.translate("DeviceTab", "Graph Channel:", None, -1))
        self.fftSubchannelLabel.setText(QtWidgets.QApplication.translate("DeviceTab", "Frequency Subchannel:", None, -1))
        self.serialNumberLabel.setText(QtWidgets.QApplication.translate("DeviceTab", "Serial Number:", None, -1))
        self.userTag2.setText(QtWidgets.QApplication.translate("DeviceTab", "User Tag 2", None, -1))
        self.userTag1.setText(QtWidgets.QApplication.translate("DeviceTab", "User Tag 1", None, -1))
        self.userTag2Label.setText(QtWidgets.QApplication.translate("DeviceTab", "User Tag 2:", None, -1))
        self.serialNumber.setText(QtWidgets.QApplication.translate("DeviceTab", "Serial Number", None, -1))
        self.userTag1Label.setText(QtWidgets.QApplication.translate("DeviceTab", "User Tag 1:", None, -1))
        self.boardInfoLabel.setText(QtWidgets.QApplication.translate("DeviceTab", "Board Info:", None, -1))
        self.boardInfo.setText(QtWidgets.QApplication.translate("DeviceTab", "Board Info", None, -1))
        self.buildInfoLabel.setText(QtWidgets.QApplication.translate("DeviceTab", "Build Info:", None, -1))
        self.buildInfo.setText(QtWidgets.QApplication.translate("DeviceTab", "Build Info", None, -1))
        self.buildDateLabel.setText(QtWidgets.QApplication.translate("DeviceTab", "Build Date:", None, -1))
        self.buildDate.setText(QtWidgets.QApplication.translate("DeviceTab", "Build Date", None, -1))
        self.bootloaderIndicator.setText(QtWidgets.QApplication.translate("DeviceTab", "Bootloader", None, -1))
        self.closeButton.setText(QtWidgets.QApplication.translate("DeviceTab", "Close", None, -1))
        self.menuButton.setText(QtWidgets.QApplication.translate("DeviceTab", "Menu", None, -1))
        self.statusLabel.setText(QtWidgets.QApplication.translate("DeviceTab", "Disconnected", None, -1))
        self.channelGroupBox.setTitle(QtWidgets.QApplication.translate("DeviceTab", "Channels", None, -1))
        self.meanLabel.setText(QtWidgets.QApplication.translate("DeviceTab", "Mean (1s)", None, -1))
        self.samplingRateLabel.setText(QtWidgets.QApplication.translate("DeviceTab", "Sampling Rate", None, -1))
        self.stdDevLabel.setText(QtWidgets.QApplication.translate("DeviceTab", "Std Dev (1s)", None, -1))
        self.LEDGroupBox.setTitle(QtWidgets.QApplication.translate("DeviceTab", "LEDs", None, -1))
        self.logGroupBox.setTitle(QtWidgets.QApplication.translate("DeviceTab", "Log", None, -1))
        self.recentLostPacketsLabel.setText(QtWidgets.QApplication.translate("DeviceTab", "Lost Packets (last 20 s):", None, -1))
        self.recentLostPackets.setText(QtWidgets.QApplication.translate("DeviceTab", "0", None, -1))
        self.actionSetUserTag1.setText(QtWidgets.QApplication.translate("DeviceTab", "Set User Tag 1", None, -1))
        self.actionSetUserTag2.setText(QtWidgets.QApplication.translate("DeviceTab", "Set User Tag 2", None, -1))
        self.actionSetUserTag2.setToolTip(QtWidgets.QApplication.translate("DeviceTab", "Set User Tag 2", None, -1))
        self.actionEditDeviceSettings.setText(QtWidgets.QApplication.translate("DeviceTab", "Edit Device Settings", None, -1))
        self.actionShowDeviceInfo.setText(QtWidgets.QApplication.translate("DeviceTab", "Show Device Information", None, -1))
        self.actionFirmwareLatestStable.setText(QtWidgets.QApplication.translate("DeviceTab", "Latest Stable", None, -1))
        self.actionFirmwareLatestStable.setToolTip(QtWidgets.QApplication.translate("DeviceTab", "Update Firmware From Latest Stable", None, -1))
        self.actionShowPacketStats.setText(QtWidgets.QApplication.translate("DeviceTab", "Show Packet Stats", None, -1))
        self.actionChangeActiveStreams.setText(QtWidgets.QApplication.translate("DeviceTab", "Change Active Streams", None, -1))
        self.actionRunTests.setText(QtWidgets.QApplication.translate("DeviceTab", "Run Hardware Tests", None, -1))
        self.actionSetDeviceMode.setText(QtWidgets.QApplication.translate("DeviceTab", "Set Device Mode", None, -1))
        self.actionFirmwareFromBranch.setText(QtWidgets.QApplication.translate("DeviceTab", "From Branch", None, -1))
        self.actionFirmwareFromBranch.setToolTip(QtWidgets.QApplication.translate("DeviceTab", "Update Firmware From Branch", None, -1))
        self.actionFirmwareFromCommit.setText(QtWidgets.QApplication.translate("DeviceTab", "From Specific Commit", None, -1))
        self.actionFirmwareFromCommit.setToolTip(QtWidgets.QApplication.translate("DeviceTab", "Update Firmware From Specific Commit", None, -1))
        self.actionFirmwareFromFile.setText(QtWidgets.QApplication.translate("DeviceTab", "From File", None, -1))
        self.actionFirmwareFromFile.setToolTip(QtWidgets.QApplication.translate("DeviceTab", "Update Firmware From File", None, -1))
        self.actionForceRunBootloader.setText(QtWidgets.QApplication.translate("DeviceTab", "Force Run Bootloader", None, -1))
        self.actionForceRunApplication.setText(QtWidgets.QApplication.translate("DeviceTab", "Force Run Application", None, -1))
        self.actionForceRunApplication.setToolTip(QtWidgets.QApplication.translate("DeviceTab", "Force Run Application", None, -1))
        self.actionForceReset.setText(QtWidgets.QApplication.translate("DeviceTab", "Force Reset", None, -1))
        self.actionForceReset.setToolTip(QtWidgets.QApplication.translate("DeviceTab", "Force Reset", None, -1))
        self.actionRaiseException.setText(QtWidgets.QApplication.translate("DeviceTab", "Raise Exception", None, -1))
        self.actionRaiseException.setToolTip(QtWidgets.QApplication.translate("DeviceTab", "Raise Exception", None, -1))
        self.actionRecoverNVM.setText(QtWidgets.QApplication.translate("DeviceTab", "Recover NVM", None, -1))
        self.actionRecoverNVM.setToolTip(QtWidgets.QApplication.translate("DeviceTab", "Recover NVM", None, -1))
        self.actionCalibrate.setText(QtWidgets.QApplication.translate("DeviceTab", "Start Calibration", None, -1))
        self.actionShakerCalibrate.setText(QtWidgets.QApplication.translate("DeviceTab", "1g RMS Shaker Calibration", None, -1))
        self.actionShakerCalibrate.setToolTip(QtWidgets.QApplication.translate("DeviceTab", "1g RMS Shaker Calibration", None, -1))

from pyqtgraph import GraphicsLayoutWidget



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ctrl_var_widget.ui',
# licensing of 'ctrl_var_widget.ui' applies.
#
# Created: Sun Mar 31 19:42:16 2019
#      by: pyside2-uic  running on PySide2 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_CtrlVarWidget(object):
    def setupUi(self, CtrlVarWidget):
        CtrlVarWidget.setObjectName("CtrlVarWidget")
        CtrlVarWidget.resize(121, 19)
        self.horizontalLayout = QtWidgets.QHBoxLayout(CtrlVarWidget)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.nameLabel = QtWidgets.QLabel(CtrlVarWidget)
        self.nameLabel.setObjectName("nameLabel")
        self.horizontalLayout.addWidget(self.nameLabel)
        self.slider = QtWidgets.QSlider(CtrlVarWidget)
        self.slider.setMinimumSize(QtCore.QSize(50, 0))
        self.slider.setOrientation(QtCore.Qt.Horizontal)
        self.slider.setObjectName("slider")
        self.horizontalLayout.addWidget(self.slider)

        self.retranslateUi(CtrlVarWidget)
        QtCore.QMetaObject.connectSlotsByName(CtrlVarWidget)

    def retranslateUi(self, CtrlVarWidget):
        CtrlVarWidget.setWindowTitle(QtWidgets.QApplication.translate("CtrlVarWidget", "Ctrl Var Widget", None, -1))
        self.nameLabel.setText(QtWidgets.QApplication.translate("CtrlVarWidget", "Ctrl Var Name", None, -1))




import os

from PySide2 import QtCore, QtWidgets

from hyperborea.preferences import *

from .ui_preferences import Ui_PreferencesDialog


class PreferencesDialog(QtWidgets.QDialog, Ui_PreferencesDialog):
    def __init__(self, parent=None):
        super().__init__(parent)

        self.settings = QtCore.QSettings()

        self.setupUi(self)

        # this is easily forgotten in Qt Designer
        self.tabWidget.setCurrentIndex(0)

        self.accepted.connect(self.write_settings)
        self.browseButton.clicked.connect(self.browse_cb)

        self.read_settings()

    def browse_cb(self):
        base_dir = self.outputLocation.text()
        base_dir = QtWidgets.QFileDialog.getExistingDirectory(self,
                                                              dir=base_dir)

        if base_dir:
            self.outputLocation.setText(base_dir)

    def read_settings(self):
        self.unitPreferences.read_settings()

        base_dir = self.settings.value("BasePath")
        if not base_dir:
            documents_path = QtCore.QStandardPaths.writableLocation(
                QtCore.QStandardPaths.DocumentsLocation)
            app_name = QtWidgets.QApplication.applicationName()
            base_dir = os.path.join(documents_path, app_name + " Data")
        self.outputLocation.setText(base_dir)
        self.outputLocation.setCursorPosition(0)

        auto_rgb = read_bool_setting(self.settings, "AutoRGB", True)
        self.automaticRGBCheckBox.setChecked(auto_rgb)

        downsample = read_bool_setting(self.settings, "Downsample", True)
        self.downsampleCheckBox.setChecked(downsample)

        compression_level = read_int_setting(self.settings,
                                             "CompressionLevel", 6)
        self.compressionLevel.setValue(compression_level)

        self.settings.beginGroup("Upload")
        upload_enabled = read_bool_setting(self.settings, "Enabled", False)
        self.enableUpload.setChecked(upload_enabled)
        s3_bucket = self.settings.value("S3Bucket")
        if s3_bucket:
            self.s3Bucket.setText(s3_bucket.strip())
        aws_region = self.settings.value("AWSRegion")
        if aws_region:
            self.awsRegion.setText(aws_region.strip())
        upload_directory = self.settings.value("Directory")
        if upload_directory:
            self.uploadDirectory.setText(upload_directory.strip())
        access_key_id = self.settings.value("AccessKeyID")
        if access_key_id:
            self.uploadAccessKeyID.setText(access_key_id.strip())
        secret_access_key = self.settings.value("SecretAccessKey")
        if secret_access_key:
            self.uploadSecretAccessKey.setText(secret_access_key.strip())
        delete_original = read_bool_setting(self.settings, "DeleteOriginal",
                                            False)
        self.uploadDeleteOriginal.setChecked(delete_original)
        self.settings.endGroup()

    def write_settings(self):
        self.unitPreferences.write_settings()

        base_dir = self.outputLocation.text()
        self.settings.setValue("BasePath", base_dir)

        auto_rgb = self.automaticRGBCheckBox.isChecked()
        write_bool_setting(self.settings, "AutoRGB", auto_rgb)

        downsample = self.downsampleCheckBox.isChecked()
        write_bool_setting(self.settings, "Downsample", downsample)

        compression_level = self.compressionLevel.value()
        self.settings.setValue("CompressionLevel", compression_level)

        self.settings.beginGroup("Upload")
        upload_enabled = self.enableUpload.isChecked()
        write_bool_setting(self.settings, "Enabled", upload_enabled)
        s3_bucket = self.s3Bucket.text().strip()
        self.settings.setValue("S3Bucket", s3_bucket)
        aws_region = self.awsRegion.text().strip()
        self.settings.setValue("AWSRegion", aws_region)
        upload_directory = self.uploadDirectory.text().strip()
        self.settings.setValue("Directory", upload_directory)
        access_key_id = self.uploadAccessKeyID.text().strip()
        self.settings.setValue("AccessKeyID", access_key_id)
        secret_access_key = self.uploadSecretAccessKey.text().strip()
        self.settings.setValue("SecretAccessKey", secret_access_key)
        delete_original = self.uploadDeleteOriginal.isChecked()
        write_bool_setting(self.settings, "DeleteOriginal", delete_original)
        self.settings.endGroup()



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'download_firmware_dialog.ui',
# licensing of 'download_firmware_dialog.ui' applies.
#
# Created: Mon May 13 14:06:33 2019
#      by: pyside2-uic  running on PySide2 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_DownloadFirmwareDialog(object):
    def setupUi(self, DownloadFirmwareDialog):
        DownloadFirmwareDialog.setObjectName("DownloadFirmwareDialog")
        DownloadFirmwareDialog.resize(374, 147)
        self.formLayout = QtWidgets.QFormLayout(DownloadFirmwareDialog)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.boardRadioButton = QtWidgets.QRadioButton(DownloadFirmwareDialog)
        self.boardRadioButton.setChecked(False)
        self.boardRadioButton.setObjectName("boardRadioButton")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.boardRadioButton)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.boardName = QtWidgets.QLineEdit(DownloadFirmwareDialog)
        self.boardName.setMinimumSize(QtCore.QSize(200, 0))
        self.boardName.setObjectName("boardName")
        self.horizontalLayout.addWidget(self.boardName)
        self.revLabel = QtWidgets.QLabel(DownloadFirmwareDialog)
        self.revLabel.setObjectName("revLabel")
        self.horizontalLayout.addWidget(self.revLabel)
        self.boardRev = QtWidgets.QSpinBox(DownloadFirmwareDialog)
        self.boardRev.setMaximum(255)
        self.boardRev.setProperty("value", 1)
        self.boardRev.setObjectName("boardRev")
        self.horizontalLayout.addWidget(self.boardRev)
        self.formLayout.setLayout(0, QtWidgets.QFormLayout.FieldRole, self.horizontalLayout)
        self.repoRadioButton = QtWidgets.QRadioButton(DownloadFirmwareDialog)
        self.repoRadioButton.setObjectName("repoRadioButton")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.repoRadioButton)
        self.repoName = QtWidgets.QLineEdit(DownloadFirmwareDialog)
        self.repoName.setEnabled(False)
        self.repoName.setObjectName("repoName")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.repoName)
        self.branchRadioButton = QtWidgets.QRadioButton(DownloadFirmwareDialog)
        self.branchRadioButton.setChecked(True)
        self.branchRadioButton.setObjectName("branchRadioButton")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.branchRadioButton)
        self.branchName = QtWidgets.QLineEdit(DownloadFirmwareDialog)
        self.branchName.setObjectName("branchName")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.branchName)
        self.commitRadioButton = QtWidgets.QRadioButton(DownloadFirmwareDialog)
        self.commitRadioButton.setObjectName("commitRadioButton")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.commitRadioButton)
        self.commitHash = QtWidgets.QLineEdit(DownloadFirmwareDialog)
        self.commitHash.setEnabled(False)
        self.commitHash.setObjectName("commitHash")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.commitHash)
        self.buttonBox = QtWidgets.QDialogButtonBox(DownloadFirmwareDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.SpanningRole, self.buttonBox)

        self.retranslateUi(DownloadFirmwareDialog)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("accepted()"), DownloadFirmwareDialog.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("rejected()"), DownloadFirmwareDialog.reject)
        QtCore.QObject.connect(self.boardRadioButton, QtCore.SIGNAL("toggled(bool)"), self.boardName.setEnabled)
        QtCore.QObject.connect(self.boardRadioButton, QtCore.SIGNAL("toggled(bool)"), self.boardRev.setEnabled)
        QtCore.QObject.connect(self.repoRadioButton, QtCore.SIGNAL("toggled(bool)"), self.repoName.setEnabled)
        QtCore.QObject.connect(self.branchRadioButton, QtCore.SIGNAL("toggled(bool)"), self.branchName.setEnabled)
        QtCore.QObject.connect(self.commitRadioButton, QtCore.SIGNAL("toggled(bool)"), self.commitHash.setEnabled)
        QtCore.QMetaObject.connectSlotsByName(DownloadFirmwareDialog)
        DownloadFirmwareDialog.setTabOrder(self.boardRadioButton, self.boardName)
        DownloadFirmwareDialog.setTabOrder(self.boardName, self.boardRev)
        DownloadFirmwareDialog.setTabOrder(self.boardRev, self.repoRadioButton)
        DownloadFirmwareDialog.setTabOrder(self.repoRadioButton, self.repoName)
        DownloadFirmwareDialog.setTabOrder(self.repoName, self.branchRadioButton)
        DownloadFirmwareDialog.setTabOrder(self.branchRadioButton, self.branchName)
        DownloadFirmwareDialog.setTabOrder(self.branchName, self.commitRadioButton)
        DownloadFirmwareDialog.setTabOrder(self.commitRadioButton, self.commitHash)
        DownloadFirmwareDialog.setTabOrder(self.commitHash, self.buttonBox)

    def retranslateUi(self, DownloadFirmwareDialog):
        DownloadFirmwareDialog.setWindowTitle(QtWidgets.QApplication.translate("DownloadFirmwareDialog", "Download Firmware", None, -1))
        self.boardRadioButton.setText(QtWidgets.QApplication.translate("DownloadFirmwareDialog", "Board", None, -1))
        self.revLabel.setText(QtWidgets.QApplication.translate("DownloadFirmwareDialog", "Rev", None, -1))
        self.repoRadioButton.setText(QtWidgets.QApplication.translate("DownloadFirmwareDialog", "Repository", None, -1))
        self.branchRadioButton.setText(QtWidgets.QApplication.translate("DownloadFirmwareDialog", "Branch", None, -1))
        self.branchName.setText(QtWidgets.QApplication.translate("DownloadFirmwareDialog", "master", None, -1))
        self.commitRadioButton.setText(QtWidgets.QApplication.translate("DownloadFirmwareDialog", "Commit", None, -1))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'change_stream_dialog.ui',
# licensing of 'change_stream_dialog.ui' applies.
#
# Created: Sun Mar 31 19:42:15 2019
#      by: pyside2-uic  running on PySide2 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_ChangeStreamDialog(object):
    def setupUi(self, ChangeStreamDialog):
        ChangeStreamDialog.setObjectName("ChangeStreamDialog")
        ChangeStreamDialog.resize(403, 49)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(ChangeStreamDialog)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName("verticalLayout")
        self.verticalLayout_2.addLayout(self.verticalLayout)
        self.buttonBox = QtWidgets.QDialogButtonBox(ChangeStreamDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.verticalLayout_2.addWidget(self.buttonBox)

        self.retranslateUi(ChangeStreamDialog)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("accepted()"), ChangeStreamDialog.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL("rejected()"), ChangeStreamDialog.reject)
        QtCore.QMetaObject.connectSlotsByName(ChangeStreamDialog)

    def retranslateUi(self, ChangeStreamDialog):
        ChangeStreamDialog.setWindowTitle(QtWidgets.QApplication.translate("ChangeStreamDialog", "Change Streams", None, -1))




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'rf_power_panel.ui',
# licensing of 'rf_power_panel.ui' applies.
#
# Created: Sun Mar 31 19:42:18 2019
#      by: pyside2-uic  running on PySide2 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_RFPowerPanel(object):
    def setupUi(self, RFPowerPanel):
        RFPowerPanel.setObjectName("RFPowerPanel")
        RFPowerPanel.resize(111, 99)
        self.verticalLayout = QtWidgets.QVBoxLayout(RFPowerPanel)
        self.verticalLayout.setObjectName("verticalLayout")
        self.enableButton = QtWidgets.QPushButton(RFPowerPanel)
        self.enableButton.setObjectName("enableButton")
        self.verticalLayout.addWidget(self.enableButton)
        self.disableButton = QtWidgets.QPushButton(RFPowerPanel)
        self.disableButton.setObjectName("disableButton")
        self.verticalLayout.addWidget(self.disableButton)
        self.ctrlVarLayout = QtWidgets.QVBoxLayout()
        self.ctrlVarLayout.setObjectName("ctrlVarLayout")
        self.verticalLayout.addLayout(self.ctrlVarLayout)
        spacerItem = QtWidgets.QSpacerItem(10, 10, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem)

        self.retranslateUi(RFPowerPanel)
        QtCore.QMetaObject.connectSlotsByName(RFPowerPanel)

    def retranslateUi(self, RFPowerPanel):
        RFPowerPanel.setWindowTitle(QtWidgets.QApplication.translate("RFPowerPanel", "RF Power Panel", None, -1))
        RFPowerPanel.setTitle(QtWidgets.QApplication.translate("RFPowerPanel", "RF Power", None, -1))
        self.enableButton.setText(QtWidgets.QApplication.translate("RFPowerPanel", "Enable RF Power", None, -1))
        self.disableButton.setText(QtWidgets.QApplication.translate("RFPowerPanel", "Disable RF Power", None, -1))

